ClientId

Enum ClientId 

pub enum ClientId {
    Domain(Domain),
    AddressLiteral(AddressLiteral),
}
Represents the identity of an client

If you connect to an MSA this can be as simple as localhost, through for smtp communication between servers or for connecting with an MX server this should be a public facing domain or ip address


MSA: Mail Submission Agent

MX: Mail Exchanger

Variants



Domain(Domain)

a registered domain



AddressLiteral(AddressLiteral)

a ipv4/ipv6 address, through theoretically others protocols are possible too

Implementations

Source

impl ClientId

pub fn localhost() -> ClientId

creates a client identity for “localhost” (here fixed to 127.0.0.1)

This can be used as client identity when connecting a mail client to a Mail Submission Agent (MSA), but should not be used when connecting to an Mail Exchanger (MX).

pub fn hostname() -> ClientId

creates a client identity using hostname (fallback localhost)

This uses the hostname crate to create a client identity. If this fails ClientId::localhost() is used.

pub fn try_hostname() -> Option<ClientId>

creates a client identity if a hostname can be found

Implementation Note

As the hostname crate currently only returns an Option we also do so.